import sys
import pathlib
import yaml
from .schemas.common import db
from .schemas.people import Person, PersonLink, PersonSource, PersonRole, PersonOffice




def to_links(person, dict_list, cls):
    for dl in dict_list:
        cls.create(
            person=person,
            url=dl.pop("url"),
            note=dl.pop("note", ""),
        )

def load_people_yaml(dir_path: pathlib.Path):
    # ensure all tables exist
    db.create_tables([Person, PersonLink, PersonSource, PersonRole, PersonOffice])

    files = list(dir_path.glob("*.yml"))
    print(f"preparing to load {len(files)} files")
    for file in files:
        pdata = yaml.safe_load(file.read_text())

        person = Person.create(
            id=pdata.pop("id"),
            name=pdata.pop("name"),
            given_name=pdata.pop("given_name"),
            family_name=pdata.pop("family_name"),
            birth_date=pdata.pop("birth_date", None),
            gender=pdata.pop("gender"),
            email=pdata.pop("email", ""),
            image=pdata.pop("image"),
            party=pdata.pop("party"),
            extras=pdata.pop("extras", {}),
        )
        to_links(person, pdata.pop("links"), PersonLink)
        to_links(person, pdata.pop("sources"), PersonSource)

        for role in pdata.pop("roles"):
            PersonRole.create(
                person=person,
                jurisdiction=role.pop("jurisdiction"),
                district=role.pop("district"),
                type=role.pop('type'),
                start_date=role.pop('start_date', None),
                end_date=role.pop('end_date', None),
            )
        for office in pdata.pop("offices"):
            PersonOffice.create(
                person=person,
                classification=office.pop("classification"),
                address=office.pop("address", ""),
                voice=office.pop("voice", ""),
                fax=office.pop("fax",""),
            )

        # currently not using other_names, other_identifiers
        if pdata.keys():
            print(pdata.keys(), "left unused")



if __name__ == "__main__":
    path = pathlib.Path(sys.argv[1])
    load_people_yaml(path)
